@@ -16,10 +16,15 @@ package org.codehaus.plexus.util;
  * limitations under the License.
  */
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.io.ByteArrayInputStream;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
@@ -27,19 +32,30 @@ import java.io.OutputStreamWriter;
 import java.io.Reader;
 import java.io.Writer;
 import java.net.URL;
+import java.nio.file.Files;
+import java.nio.file.Paths;
 import java.util.Properties;
 
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TestName;
+
 /**
  * This is used to test FileUtils for correctness.
  *
  * @author Peter Donald
  * @author Matthew Hawthorne
- * @version $Id$
  * @see FileUtils
+ * @version $Id: $Id
+ * @since 3.4.0
  */
 public final class FileUtilsTest
     extends FileBasedTestCase
 {
+    @Rule
+    public TestName name = new TestName();
+
     // Test data
 
     /**
@@ -55,6 +71,11 @@ public final class FileUtilsTest
 
     private static int testFile2Size;
 
+    /**
+     * <p>Constructor for FileUtilsTest.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
     public FileUtilsTest()
         throws Exception
     {
@@ -66,9 +87,12 @@ public final class FileUtilsTest
     }
 
     /**
-     * @see junit.framework.TestCase#setUp()
+     * <p>setUp.</p>
+     *
+     * @throws java.lang.Exception if any.
      */
-    protected void setUp()
+    @Before
+    public void setUp()
         throws Exception
     {
         getTestDirectory().mkdirs();
@@ -82,6 +106,10 @@ public final class FileUtilsTest
 
     // byteCountToDisplaySize
 
+    /**
+     * <p>testByteCountToDisplaySize.</p>
+     */
+    @Test
     public void testByteCountToDisplaySize()
     {
         assertEquals( FileUtils.byteCountToDisplaySize( 0 ), "0 bytes" );
@@ -92,6 +120,10 @@ public final class FileUtilsTest
 
     // waitFor
 
+    /**
+     * <p>testWaitFor.</p>
+     */
+    @Test
     public void testWaitFor()
     {
         FileUtils.waitFor( "", -1 );
@@ -99,6 +131,12 @@ public final class FileUtilsTest
         FileUtils.waitFor( "", 2 );
     }
 
+    /**
+     * <p>testToFile.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testToFile()
         throws Exception
     {
@@ -108,6 +146,12 @@ public final class FileUtilsTest
         assertEquals( "name #%20?{}[]<>.txt", file.getName() );
     }
 
+    /**
+     * <p>testToFileBadProtocol.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testToFileBadProtocol()
         throws Exception
     {
@@ -116,6 +160,12 @@ public final class FileUtilsTest
         assertNull( file );
     }
 
+    /**
+     * <p>testToFileNull.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testToFileNull()
         throws Exception
     {
@@ -124,22 +174,32 @@ public final class FileUtilsTest
     }
 
     // Hacked to sanity by Trygve
+    /**
+     * <p>testToURLs.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testToURLs()
         throws Exception
     {
-        File[] files = new File[]{ new File( "file1" ), new File( "file2" ), };
+        File[] files = new File[] { new File( "file1" ), new File( "file2" ), };
 
         URL[] urls = FileUtils.toURLs( files );
 
         assertEquals( "The length of the generated URL's is not equals to the length of files. " + "Was " + files.length
-                          + ", expected " + urls.length, files.length, urls.length );
+            + ", expected " + urls.length, files.length, urls.length );
 
         for ( int i = 0; i < urls.length; i++ )
         {
-            assertEquals( files[i].toURL(), urls[i] );
+            assertEquals( files[i].toURI().toURL(), urls[i] );
         }
     }
 
+    /**
+     * <p>testGetFilesFromExtension.</p>
+     */
+    @Test
     public void testGetFilesFromExtension()
     {
         // TODO I'm not sure what is supposed to happen here
@@ -147,22 +207,23 @@ public final class FileUtilsTest
 
         // Non-existent files
         final String[] emptyFileNames =
-            FileUtils.getFilesFromExtension( getTestDirectory().getAbsolutePath(), new String[]{ "java" } );
+            FileUtils.getFilesFromExtension( getTestDirectory().getAbsolutePath(), new String[] { "java" } );
         assertTrue( emptyFileNames.length == 0 );
 
         // Existing files
         // TODO Figure out how to test this
         /*
-        final String[] fileNames =
-            FileUtils.getFilesFromExtension(
-                getClass().getResource("/java/util/").getFile(),
-                new String[] { "class" });
-        assertTrue(fileNames.length > 0);
-        */
+         * final String[] fileNames = FileUtils.getFilesFromExtension( getClass().getResource("/java/util/").getFile(),
+         * new String[] { "class" }); assertTrue(fileNames.length > 0);
+         */
     }
 
     // mkdir
 
+    /**
+     * <p>testMkdir.</p>
+     */
+    @Test
     public void testMkdir()
     {
         final File dir = new File( getTestDirectory(), "testdir" );
@@ -187,11 +248,17 @@ public final class FileUtilsTest
 
     // contentEquals
 
+    /**
+     * <p>testContentEquals.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testContentEquals()
         throws Exception
     {
         // Non-existent files
-        final File file = new File( getTestDirectory(), getName() );
+        final File file = new File( getTestDirectory(), name.getMethodName() );
         assertTrue( FileUtils.contentEquals( file, file ) );
 
         // TODO Should comparing 2 directories throw an Exception instead of returning false?
@@ -199,11 +266,11 @@ public final class FileUtilsTest
         assertTrue( !FileUtils.contentEquals( getTestDirectory(), getTestDirectory() ) );
 
         // Different files
-        final File objFile1 = new File( getTestDirectory(), getName() + ".object" );
+        final File objFile1 = new File( getTestDirectory(), name.getMethodName() + ".object" );
         objFile1.deleteOnExit();
         FileUtils.copyURLToFile( getClass().getResource( "/java/lang/Object.class" ), objFile1 );
 
-        final File objFile2 = new File( getTestDirectory(), getName() + ".collection" );
+        final File objFile2 = new File( getTestDirectory(), name.getMethodName() + ".collection" );
         objFile2.deleteOnExit();
         FileUtils.copyURLToFile( getClass().getResource( "/java/util/Collection.class" ), objFile2 );
 
@@ -216,27 +283,43 @@ public final class FileUtilsTest
 
     // removePath
 
+    /**
+     * <p>testRemovePath.</p>
+     */
+    @Test
     public void testRemovePath()
     {
-        final String fileName = FileUtils.removePath( new File( getTestDirectory(), getName() ).getAbsolutePath() );
-        assertEquals( getName(), fileName );
+        final String fileName =
+            FileUtils.removePath( new File( getTestDirectory(), name.getMethodName() ).getAbsolutePath() );
+        assertEquals( name.getMethodName(), fileName );
     }
 
     // getPath
 
+    /**
+     * <p>testGetPath.</p>
+     */
+    @Test
     public void testGetPath()
     {
-        final String fileName = FileUtils.getPath( new File( getTestDirectory(), getName() ).getAbsolutePath() );
+        final String fileName =
+            FileUtils.getPath( new File( getTestDirectory(), name.getMethodName() ).getAbsolutePath() );
         assertEquals( getTestDirectory().getAbsolutePath(), fileName );
     }
 
     // copyURLToFile
 
+    /**
+     * <p>testCopyURLToFile.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testCopyURLToFile()
         throws Exception
     {
         // Creates file
-        final File file = new File( getTestDirectory(), getName() );
+        final File file = new File( getTestDirectory(), name.getMethodName() );
         file.deleteOnExit();
 
         // Loads resource
@@ -244,7 +327,7 @@ public final class FileUtilsTest
         FileUtils.copyURLToFile( getClass().getResource( resourceName ), file );
 
         // Tests that resource was copied correctly
-        final FileInputStream fis = new FileInputStream( file );
+        final InputStream fis = Files.newInputStream( file.toPath() );
         try
         {
             assertTrue( "Content is not equal.",
@@ -258,11 +341,15 @@ public final class FileUtilsTest
 
     // catPath
 
+    /**
+     * <p>testCatPath.</p>
+     */
+    @Test
     public void testCatPath()
     {
         // TODO StringIndexOutOfBoundsException thrown if file doesn't contain slash.
         // Is this acceptable?
-        //assertEquals("", FileUtils.catPath("a", "b"));
+        // assertEquals("", FileUtils.catPath("a", "b"));
 
         assertEquals( "/a/c", FileUtils.catPath( "/a/b", "c" ) );
         assertEquals( "/a/d", FileUtils.catPath( "/a/b/c", "../d" ) );
@@ -270,6 +357,12 @@ public final class FileUtilsTest
 
     // forceMkdir
 
+    /**
+     * <p>testForceMkdir.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testForceMkdir()
         throws Exception
     {
@@ -277,7 +370,7 @@ public final class FileUtilsTest
         FileUtils.forceMkdir( getTestDirectory() );
 
         // Creates test file
-        final File testFile = new File( getTestDirectory(), getName() );
+        final File testFile = new File( getTestDirectory(), name.getMethodName() );
         testFile.deleteOnExit();
         testFile.createNewFile();
         assertTrue( "Test file does not exist.", testFile.exists() );
@@ -316,10 +409,16 @@ public final class FileUtilsTest
 
     // sizeOfDirectory
 
+    /**
+     * <p>testSizeOfDirectory.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testSizeOfDirectory()
         throws Exception
     {
-        final File file = new File( getTestDirectory(), getName() );
+        final File file = new File( getTestDirectory(), name.getMethodName() );
 
         // Non-existent file
         try
@@ -356,11 +455,20 @@ public final class FileUtilsTest
 
     // TODO Finish test
 
+    /**
+     * <p>XtestIsFileNewer.</p>
+     */
     public void XtestIsFileNewer()
     {
     }
 
     // copyFile
+    /**
+     * <p>testCopyFile1.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testCopyFile1()
         throws Exception
     {
@@ -370,6 +478,12 @@ public final class FileUtilsTest
         assertTrue( "Check Full copy", destination.length() == testFile1Size );
     }
 
+    /**
+     * <p>testCopyFile2.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testCopyFile2()
         throws Exception
     {
@@ -380,10 +494,11 @@ public final class FileUtilsTest
     }
 
     /**
-     * ensure we create  directory tree for destination
+     * ensure we create directory tree for destination
      *
-     * @throws Exception
+     * @throws java.lang.Exception
      */
+    @Test
     public void testCopyFile3()
         throws Exception
     {
@@ -398,8 +513,68 @@ public final class FileUtilsTest
         assertTrue( "Check Full copy", destination.length() == testFile2Size );
     }
 
+    // linkFile
+    /**
+     * <p>testLinkFile1.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
+    public void testLinkFile1()
+        throws Exception
+    {
+        final File destination = new File( getTestDirectory(), "link1.txt" );
+        FileUtils.linkFile( testFile1, destination );
+        assertTrue( "Check Exist", destination.exists() );
+        assertTrue( "Check File length", destination.length() == testFile1Size );
+        assertTrue( "Check is link", Files.isSymbolicLink(destination.toPath()));
+    }
+
+    /**
+     * <p>testLinkFile2.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
+    public void testLinkFile2()
+        throws Exception
+    {
+        final File destination = new File( getTestDirectory(), "link2.txt" );
+        FileUtils.linkFile( testFile1, destination );
+        assertTrue( "Check Exist", destination.exists() );
+        assertTrue( "Check File length", destination.length() == testFile2Size );
+        assertTrue( "Check is link", Files.isSymbolicLink(destination.toPath()));
+    }
+
+    /**
+     * ensure we create directory tree for destination
+     *
+     * @throws java.lang.Exception
+     */
+    @Test
+    public void testLinkFile3()
+        throws Exception
+    {
+        File destDirectory = new File( getTestDirectory(), "foo/bar/testlink" );
+        if ( destDirectory.exists() )
+        {
+            destDirectory.delete();
+        }
+        final File destination = new File( destDirectory, "link2.txt" );
+        FileUtils.linkFile( testFile1, destination );
+        assertTrue( "Check Exist", destination.exists() );
+        assertTrue( "Check File length", destination.length() == testFile2Size );
+        assertTrue( "Check is link", Files.isSymbolicLink(destination.toPath()));
+    }
+
     // copyFileIfModified
 
+    /**
+     * <p>testCopyIfModifiedWhenSourceIsNewer.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testCopyIfModifiedWhenSourceIsNewer()
         throws Exception
     {
@@ -415,12 +590,19 @@ public final class FileUtilsTest
         // Place source
         File source = new File( getTestDirectory(), "copy1.txt" );
         FileUtils.copyFile( testFile1, source );
+        source.setLastModified( System.currentTimeMillis() );
 
         // Copy will occur when source is newer
         assertTrue( "Failed copy. Target file should have been updated.",
                     FileUtils.copyFileIfModified( source, destination ) );
     }
 
+    /**
+     * <p>testCopyIfModifiedWhenSourceIsOlder.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testCopyIfModifiedWhenSourceIsOlder()
         throws Exception
     {
@@ -430,19 +612,48 @@ public final class FileUtilsTest
         File source = new File( getTestDirectory() + "copy1.txt" );
         FileUtils.copyFile( testFile1, source );
 
-        // Make sure desintation is newer
+        // Make sure destination is newer
         reallySleep( 1000 );
 
         // Place destination
-        File desintation = new File( getTestDirectory(), "/temp/copy1.txt" );
-        FileUtils.copyFile( testFile1, desintation );
+        File destination = new File( getTestDirectory(), "/temp/copy1.txt" );
+        FileUtils.copyFile( testFile1, destination );
 
-        // Copy will occur when desintation is newer
-        assertFalse( "Source file should not have been copied.", FileUtils.copyFileIfModified( source, desintation ) );
+        // Copy will occur when destination is newer
+        assertFalse( "Source file should not have been copied.", FileUtils.copyFileIfModified( source, destination ) );
+    }
+
+    /**
+     * <p>testCopyIfModifiedWhenSourceHasZeroDate.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
+    public void testCopyIfModifiedWhenSourceHasZeroDate()
+        throws Exception
+    {
+        FileUtils.forceMkdir( new File( getTestDirectory(), "temp" ) );
+
+        // Source modified on 1970-01-01T00:00Z
+        File source = new File( getTestDirectory(), "copy1.txt" );
+        FileUtils.copyFile( testFile1, source );
+        source.setLastModified( 0L );
+
+        // A non existing destination
+        File destination = new File( getTestDirectory(), "temp/copy1.txt" );
+
+        // Should copy the source to the non existing destination.
+        assertTrue( "Source file should have been copied.", FileUtils.copyFileIfModified( source, destination ) );
     }
 
     // forceDelete
 
+    /**
+     * <p>testForceDeleteAFile1.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testForceDeleteAFile1()
         throws Exception
     {
@@ -453,6 +664,12 @@ public final class FileUtilsTest
         assertTrue( "Check No Exist", !destination.exists() );
     }
 
+    /**
+     * <p>testForceDeleteAFile2.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testForceDeleteAFile2()
         throws Exception
     {
@@ -465,6 +682,12 @@ public final class FileUtilsTest
 
     // copyFileToDirectory
 
+    /**
+     * <p>testCopyFile1ToDir.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testCopyFile1ToDir()
         throws Exception
     {
@@ -479,6 +702,12 @@ public final class FileUtilsTest
         assertTrue( "Check Full copy", destination.length() == testFile1Size );
     }
 
+    /**
+     * <p>testCopyFile2ToDir.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testCopyFile2ToDir()
         throws Exception
     {
@@ -495,6 +724,12 @@ public final class FileUtilsTest
 
     // copyFileToDirectoryIfModified
 
+    /**
+     * <p>testCopyFile1ToDirIfModified.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testCopyFile1ToDirIfModified()
         throws Exception
     {
@@ -520,6 +755,12 @@ public final class FileUtilsTest
         assertTrue( "Timestamp was changed", timestamp == target.lastModified() );
     }
 
+    /**
+     * <p>testCopyFile2ToDirIfModified.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testCopyFile2ToDirIfModified()
         throws Exception
     {
@@ -547,6 +788,12 @@ public final class FileUtilsTest
 
     // forceDelete
 
+    /**
+     * <p>testForceDeleteDir.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testForceDeleteDir()
         throws Exception
     {
@@ -556,6 +803,12 @@ public final class FileUtilsTest
 
     // resolveFile
 
+    /**
+     * <p>testResolveFileDotDot.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testResolveFileDotDot()
         throws Exception
     {
@@ -563,6 +816,12 @@ public final class FileUtilsTest
         assertEquals( "Check .. operator", file, getTestDirectory().getParentFile() );
     }
 
+    /**
+     * <p>testResolveFileDot.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testResolveFileDot()
         throws Exception
     {
@@ -572,17 +831,21 @@ public final class FileUtilsTest
 
     // normalize
 
+    /**
+     * <p>testNormalize.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testNormalize()
         throws Exception
     {
-        final String[] src =
-            { "", "/", "///", "/foo", "/foo//", "/./", "/foo/./", "/foo/./bar", "/foo/../bar", "/foo/../bar/../baz",
-                "/foo/bar/../../baz", "/././", "/foo/./../bar", "/foo/.././bar/", "//foo//./bar", "/../",
-                "/foo/../../" };
+        final String[] src = { "", "/", "///", "/foo", "/foo//", "/./", "/foo/./", "/foo/./bar", "/foo/../bar",
+            "/foo/../bar/../baz", "/foo/bar/../../baz", "/././", "/foo/./../bar", "/foo/.././bar/", "//foo//./bar",
+            "/../", "/foo/../../" };
 
-        final String[] dest =
-            { "", "/", "/", "/foo", "/foo/", "/", "/foo/", "/foo/bar", "/bar", "/baz", "/baz", "/", "/bar", "/bar/",
-                "/foo/bar", null, null };
+        final String[] dest = { "", "/", "/", "/foo", "/foo/", "/", "/foo/", "/foo/bar", "/bar", "/baz", "/baz", "/",
+            "/bar", "/bar/", "/foo/bar", null, null };
 
         assertEquals( "Oops, test writer goofed", src.length, dest.length );
 
@@ -610,8 +873,11 @@ public final class FileUtilsTest
 
     /**
      * Test the FileUtils implementation.
+     *
+     * @throws java.lang.Exception if any.
      */
     // Used to exist as IOTestCase class
+    @Test
     public void testFileUtils()
         throws Exception
     {
@@ -620,14 +886,12 @@ public final class FileUtilsTest
         final URL url = this.getClass().getResource( path );
         assertNotNull( path + " was not found.", url );
 
-        String filename = url.getFile();
-        //The following line applies a fix for spaces in a path
-        filename = replaceAll( filename, "%20", " " );
+        final String filename = Paths.get(url.toURI()).toString();
         final String filename2 = "test2.txt";
 
         assertTrue( "test.txt extension == \"txt\"", FileUtils.getExtension( filename ).equals( "txt" ) );
 
-        assertTrue( "Test file does not exist: " + filename, FileUtils.fileExists( filename ) );
+        assertTrue( "Test file does exist: " + filename, FileUtils.fileExists( filename ) );
 
         assertTrue( "Second test file does not exist", !FileUtils.fileExists( filename2 ) );
 
@@ -649,19 +913,27 @@ public final class FileUtilsTest
 
     }
 
+    /**
+     * <p>testGetExtension.</p>
+     */
+    @Test
     public void testGetExtension()
     {
         final String[][] tests =
             { { "filename.ext", "ext" }, { "README", "" }, { "domain.dot.com", "com" }, { "image.jpeg", "jpeg" },
                 { "folder" + File.separator + "image.jpeg", "jpeg" }, { "folder" + File.separator + "README", "" } };
 
-        for ( int i = 0; i < tests.length; i++ )
+        for ( String[] test : tests )
         {
-            assertEquals( tests[i][1], FileUtils.getExtension( tests[i][0] ) );
-            //assertEquals(tests[i][1], FileUtils.extension(tests[i][0]));
+            assertEquals( test[1], FileUtils.getExtension( test[0] ) );
+            // assertEquals(tests[i][1], FileUtils.extension(tests[i][0]));
         }
     }
 
+    /**
+     * <p>testGetExtensionWithPaths.</p>
+     */
+    @Test
     public void testGetExtensionWithPaths()
     {
         // Since the utilities are based on the separator for the platform
@@ -674,52 +946,65 @@ public final class FileUtilsTest
             { "" + sep + "tmp" + sep + "foo.bar" + sep + "README", "" },
             { "C:" + sep + "temp" + sep + "foo.bar" + sep + "README", "" }, { ".." + sep + "filename.ext", "ext" },
             { "blabla", "" } };
-        for ( int i = 0; i < testsWithPaths.length; i++ )
+        for ( String[] testsWithPath : testsWithPaths )
         {
-            assertEquals( testsWithPaths[i][1], FileUtils.getExtension( testsWithPaths[i][0] ) );
-            //assertEquals(testsWithPaths[i][1], FileUtils.extension(testsWithPaths[i][0]));
+            assertEquals( testsWithPath[1], FileUtils.getExtension( testsWithPath[0] ) );
+            // assertEquals(testsWithPaths[i][1], FileUtils.extension(testsWithPaths[i][0]));
         }
     }
 
+    /**
+     * <p>testRemoveExtension.</p>
+     */
+    @Test
     public void testRemoveExtension()
     {
         final String[][] tests = { { "filename.ext", "filename" }, { "first.second.third.ext", "first.second.third" },
             { "README", "README" }, { "domain.dot.com", "domain.dot" }, { "image.jpeg", "image" } };
 
-        for ( int i = 0; i < tests.length; i++ )
+        for ( String[] test : tests )
         {
-            assertEquals( tests[i][1], FileUtils.removeExtension( tests[i][0] ) );
-            //assertEquals(tests[i][1], FileUtils.basename(tests[i][0]));
+            assertEquals( test[1], FileUtils.removeExtension( test[0] ) );
+            // assertEquals(tests[i][1], FileUtils.basename(tests[i][0]));
         }
     }
 
     /* TODO: Reenable this test */
+    /**
+     * <p>testRemoveExtensionWithPaths.</p>
+     */
+    @Test
     public void testRemoveExtensionWithPaths()
     {
         // Since the utilities are based on the separator for the platform
         // running the test, ensure we are using the right separator
         final String sep = File.separator;
-        final String[][] testsWithPaths =
-            { { sep + "tmp" + sep + "foo" + sep + "filename.ext", sep + "tmp" + sep + "foo" + sep + "filename" },
-                { "C:" + sep + "temp" + sep + "foo" + sep + "filename.ext",
-                    "C:" + sep + "temp" + sep + "foo" + sep + "filename" },
-                { sep + "tmp" + sep + "foo.bar" + sep + "filename.ext",
-                    sep + "tmp" + sep + "foo.bar" + sep + "filename" },
-                { "C:" + sep + "temp" + sep + "foo.bar" + sep + "filename.ext",
-                    "C:" + sep + "temp" + sep + "foo.bar" + sep + "filename" },
-                { sep + "tmp" + sep + "foo.bar" + sep + "README", sep + "tmp" + sep + "foo.bar" + sep + "README" },
-                { "C:" + sep + "temp" + sep + "foo.bar" + sep + "README",
-                    "C:" + sep + "temp" + sep + "foo.bar" + sep + "README" },
-                { ".." + sep + "filename.ext", ".." + sep + "filename" } };
+        final String[][] testsWithPaths = {
+            { sep + "tmp" + sep + "foo" + sep + "filename.ext", sep + "tmp" + sep + "foo" + sep + "filename" },
+            { "C:" + sep + "temp" + sep + "foo" + sep + "filename.ext",
+                "C:" + sep + "temp" + sep + "foo" + sep + "filename" },
+            { sep + "tmp" + sep + "foo.bar" + sep + "filename.ext", sep + "tmp" + sep + "foo.bar" + sep + "filename" },
+            { "C:" + sep + "temp" + sep + "foo.bar" + sep + "filename.ext",
+                "C:" + sep + "temp" + sep + "foo.bar" + sep + "filename" },
+            { sep + "tmp" + sep + "foo.bar" + sep + "README", sep + "tmp" + sep + "foo.bar" + sep + "README" },
+            { "C:" + sep + "temp" + sep + "foo.bar" + sep + "README",
+                "C:" + sep + "temp" + sep + "foo.bar" + sep + "README" },
+            { ".." + sep + "filename.ext", ".." + sep + "filename" } };
 
-        for ( int i = 0; i < testsWithPaths.length; i++ )
+        for ( String[] testsWithPath : testsWithPaths )
         {
-            assertEquals( testsWithPaths[i][1], FileUtils.removeExtension( testsWithPaths[i][0] ) );
-            //assertEquals(testsWithPaths[i][1], FileUtils.basename(testsWithPaths[i][0]));
+            assertEquals( testsWithPath[1], FileUtils.removeExtension( testsWithPath[0] ) );
+            // assertEquals(testsWithPaths[i][1], FileUtils.basename(testsWithPaths[i][0]));
         }
     }
 
-    public void testCopyDirectoryStructureWithAEmptyDirectoryStruture()
+    /**
+     * <p>testCopyDirectoryStructureWithAEmptyDirectoryStructure.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
+    public void testCopyDirectoryStructureWithAEmptyDirectoryStructure()
         throws Exception
     {
         File from = new File( getTestDirectory(), "from" );
@@ -735,6 +1020,12 @@ public final class FileUtilsTest
         FileUtils.copyDirectoryStructure( from, to );
     }
 
+    /**
+     * <p>testCopyDirectoryStructureWithAPopulatedStructure.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testCopyDirectoryStructureWithAPopulatedStructure()
         throws Exception
     {
@@ -794,6 +1085,12 @@ public final class FileUtilsTest
         checkFile( f2_1, new File( to, "2/2_1/2_1.txt" ) );
     }
 
+    /**
+     * <p>testCopyDirectoryStructureIfModified.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testCopyDirectoryStructureIfModified()
         throws Exception
     {
@@ -873,6 +1170,12 @@ public final class FileUtilsTest
 
     }
 
+    /**
+     * <p>testCopyDirectoryStructureToSelf.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testCopyDirectoryStructureToSelf()
         throws Exception
     {
@@ -914,6 +1217,12 @@ public final class FileUtilsTest
         }
     }
 
+    /**
+     * <p>testFilteredFileCopy.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testFilteredFileCopy()
         throws Exception
     {
@@ -926,7 +1235,7 @@ public final class FileUtilsTest
         filterProperties.setProperty( "s", "sample text" );
 
         // test ${token}
-        FileUtils.FilterWrapper[] wrappers1 = new FileUtils.FilterWrapper[]{ new FileUtils.FilterWrapper()
+        FileUtils.FilterWrapper[] wrappers1 = new FileUtils.FilterWrapper[] { new FileUtils.FilterWrapper()
         {
             public Reader getReader( Reader reader )
             {
@@ -945,6 +1254,12 @@ public final class FileUtilsTest
         compareFile.delete();
     }
 
+    /**
+     * <p>testFilteredWithoutFilterAndOlderFile.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testFilteredWithoutFilterAndOlderFile()
         throws Exception
     {
@@ -974,7 +1289,12 @@ public final class FileUtilsTest
 
     }
 
-
+    /**
+     * <p>testFilteredWithoutFilterAndOlderFileAndOverwrite.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testFilteredWithoutFilterAndOlderFileAndOverwrite()
         throws Exception
     {
@@ -1004,6 +1324,12 @@ public final class FileUtilsTest
 
     }
 
+    /**
+     * <p>testFileRead.</p>
+     *
+     * @throws java.io.IOException if any.
+     */
+    @Test
     public void testFileRead()
         throws IOException
     {
@@ -1019,7 +1345,7 @@ public final class FileUtilsTest
         Writer writer = null;
         try
         {
-            writer = new OutputStreamWriter( new FileOutputStream( testFile ) );
+            writer = new OutputStreamWriter( Files.newOutputStream( testFile.toPath() ) );
             writer.write( testString );
             writer.flush();
         }
@@ -1032,6 +1358,12 @@ public final class FileUtilsTest
         testFile.delete();
     }
 
+    /**
+     * <p>testFileReadWithEncoding.</p>
+     *
+     * @throws java.io.IOException if any.
+     */
+    @Test
     public void testFileReadWithEncoding()
         throws IOException
     {
@@ -1043,7 +1375,7 @@ public final class FileUtilsTest
         Writer writer = null;
         try
         {
-            writer = new OutputStreamWriter( new FileOutputStream( testFile ), encoding );
+            writer = new OutputStreamWriter( Files.newOutputStream( testFile.toPath() ), encoding );
             writer.write( testString );
             writer.flush();
         }
@@ -1056,6 +1388,12 @@ public final class FileUtilsTest
         testFile.delete();
     }
 
+    /**
+     * <p>testFileAppend.</p>
+     *
+     * @throws java.io.IOException if any.
+     */
+    @Test
     public void testFileAppend()
         throws IOException
     {
@@ -1065,7 +1403,7 @@ public final class FileUtilsTest
         Writer writer = null;
         try
         {
-            writer = new OutputStreamWriter( new FileOutputStream( testFile ) );
+            writer = new OutputStreamWriter( Files.newOutputStream( testFile.toPath() ) );
             writer.write( baseString );
             writer.flush();
         }
@@ -1080,6 +1418,12 @@ public final class FileUtilsTest
         testFile.delete();
     }
 
+    /**
+     * <p>testFileAppendWithEncoding.</p>
+     *
+     * @throws java.io.IOException if any.
+     */
+    @Test
     public void testFileAppendWithEncoding()
         throws IOException
     {
@@ -1090,7 +1434,7 @@ public final class FileUtilsTest
         Writer writer = null;
         try
         {
-            writer = new OutputStreamWriter( new FileOutputStream( testFile ), encoding );
+            writer = new OutputStreamWriter( Files.newOutputStream( testFile.toPath() ), encoding );
             writer.write( baseString );
             writer.flush();
         }
@@ -1105,6 +1449,12 @@ public final class FileUtilsTest
         testFile.delete();
     }
 
+    /**
+     * <p>testFileWrite.</p>
+     *
+     * @throws java.io.IOException if any.
+     */
+    @Test
     public void testFileWrite()
         throws IOException
     {
@@ -1117,6 +1467,12 @@ public final class FileUtilsTest
         testFile.delete();
     }
 
+    /**
+     * <p>testFileWriteWithEncoding.</p>
+     *
+     * @throws java.io.IOException if any.
+     */
+    @Test
     public void testFileWriteWithEncoding()
         throws IOException
     {
@@ -1133,11 +1489,12 @@ public final class FileUtilsTest
     /**
      * Workaround for the following Sun bugs. They are fixed in JDK 6u1 and JDK 5u11.
      *
-     * @throws Exception
+     * @throws java.lang.Exception
      * @see <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=4403166">Sun bug id=4403166</a>
      * @see <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6182812">Sun bug id=6182812</a>
      * @see <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6481955">Sun bug id=6481955</a>
      */
+    @Test
     public void testDeleteLongPathOnWindows()
         throws Exception
     {
@@ -1160,7 +1517,7 @@ public final class FileUtilsTest
         File f = new File( a1, path.toString() + "test.txt" );
 
         InputStream is = new ByteArrayInputStream( "Blabla".getBytes( "UTF-8" ) );
-        OutputStream os = new FileOutputStream( f.getCanonicalFile() );
+        OutputStream os = Files.newOutputStream( f.getCanonicalFile().toPath() );
         IOUtil.copy( is, os );
         IOUtil.close( is );
         IOUtil.close( os );
@@ -1174,7 +1531,13 @@ public final class FileUtilsTest
         }
     }
 
-    //Test for bug PLXUTILS-10
+    // Test for bug PLXUTILS-10
+    /**
+     * <p>testCopyFileOnSameFile.</p>
+     *
+     * @throws java.io.IOException if any.
+     */
+    @Test
     public void testCopyFileOnSameFile()
         throws IOException
     {
@@ -1191,6 +1554,12 @@ public final class FileUtilsTest
         assertTrue( theFile.length() > 0 );
     }
 
+    /**
+     * <p>testExtensions.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testExtensions()
         throws Exception
     {
@@ -1210,6 +1579,12 @@ public final class FileUtilsTest
         }
     }
 
+    /**
+     * <p>testIsValidWindowsFileName.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testIsValidWindowsFileName()
         throws Exception
     {
@@ -1235,6 +1610,12 @@ public final class FileUtilsTest
         }
     }
 
+    /**
+     * <p>testDeleteDirectoryWithValidFileSymlink.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testDeleteDirectoryWithValidFileSymlink()
         throws Exception
     {
@@ -1256,6 +1637,12 @@ public final class FileUtilsTest
         assertTrue( "Failed to delete test directory", !getTestDirectory().exists() );
     }
 
+    /**
+     * <p>testDeleteDirectoryWithValidDirSymlink.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testDeleteDirectoryWithValidDirSymlink()
         throws Exception
     {
@@ -1277,6 +1664,12 @@ public final class FileUtilsTest
         assertTrue( "Failed to delete test directory", !getTestDirectory().exists() );
     }
 
+    /**
+     * <p>testDeleteDirectoryWithDanglingSymlink.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testDeleteDirectoryWithDanglingSymlink()
         throws Exception
     {
@@ -1297,6 +1690,12 @@ public final class FileUtilsTest
         assertTrue( "Failed to delete test directory", !getTestDirectory().exists() );
     }
 
+    /**
+     * <p>testcopyDirectoryLayoutWithExcludesIncludes.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testcopyDirectoryLayoutWithExcludesIncludes()
         throws Exception
     {
@@ -1316,9 +1715,8 @@ public final class FileUtilsTest
         File[] childs = destination.listFiles();
         assertEquals( 2, childs.length );
 
-        for ( int i = 0, size = childs.length; i < size; i++ )
+        for ( File current : childs )
         {
-            File current = childs[i];
             if ( current.getName().endsWith( "empty-dir" ) || current.getName().endsWith( "dir1" ) )
             {
                 if ( current.getName().endsWith( "dir1" ) )
@@ -1335,10 +1733,11 @@ public final class FileUtilsTest
     }
 
     /**
-     * Be sure that {@link FileUtils#createTempFile(String, String, File)} is always unique.
+     * Be sure that {@link org.codehaus.plexus.util.FileUtils#createTempFile(String, String, File)} is always unique.
      *
-     * @throws Exception if any
+     * @throws java.lang.Exception if any
      */
+    @Test
     public void testCreateTempFile()
         throws Exception
     {
