@@ -16,34 +16,40 @@ package org.codehaus.plexus.util.xml;
  * limitations under the License.
  */
 
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.Reader;
 import java.io.StringWriter;
 import java.io.Writer;
-
-import junit.framework.TestCase;
+import java.nio.file.Files;
 
 import org.codehaus.plexus.util.IOUtil;
 import org.codehaus.plexus.util.ReaderFactory;
 import org.codehaus.plexus.util.StringUtils;
 import org.codehaus.plexus.util.WriterFactory;
+import org.junit.Test;
 
 /**
- * Test the {@link XmlUtil} class.
+ * Test the {@link org.codehaus.plexus.util.xml.XmlUtil} class.
  *
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id$
+ * @version $Id: $Id
+ * @since 3.4.0
  */
 public class XmlUtilTest
-    extends TestCase
 {
     private String basedir;
 
+    /**
+     * <p>Getter for the field <code>basedir</code>.</p>
+     *
+     * @return a {@link java.lang.String} object.
+     */
     public final String getBasedir()
     {
         if ( null == basedir )
@@ -51,7 +57,7 @@ public class XmlUtilTest
             basedir = System.getProperty( "basedir", new File( "" ).getAbsolutePath() );
         }
         return basedir;
-    }    
+    }
 
     private File getTestOutputFile( String relPath )
         throws IOException
@@ -65,20 +71,12 @@ public class XmlUtilTest
         return file;
     }
 
-    /** {@inheritDoc} */
-    protected void setUp()
-        throws Exception
-    {
-        super.setUp();
-    }
-
-    /** {@inheritDoc} */
-    protected void tearDown()
-        throws Exception
-    {
-        super.tearDown();
-    }
-
+    /**
+     * <p>testPrettyFormatInputStreamOutputStream.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testPrettyFormatInputStreamOutputStream()
         throws Exception
     {
@@ -89,8 +87,8 @@ public class XmlUtilTest
         OutputStream os = null;
         try
         {
-            is = new FileInputStream( testDocument );
-            os = new FileOutputStream( getTestOutputFile( "target/test/prettyFormatTestDocumentOutputStream.xml" ) );
+            is = Files.newInputStream( testDocument.toPath() );
+            os = Files.newOutputStream( getTestOutputFile( "target/test/prettyFormatTestDocumentOutputStream.xml" ).toPath() );
 
             assertNotNull( is );
             assertNotNull( os );
@@ -104,6 +102,12 @@ public class XmlUtilTest
         }
     }
 
+    /**
+     * <p>testPrettyFormatReaderWriter.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testPrettyFormatReaderWriter()
         throws Exception
     {
@@ -115,7 +119,8 @@ public class XmlUtilTest
         try
         {
             reader = ReaderFactory.newXmlReader( testDocument );
-            writer = WriterFactory.newXmlWriter( getTestOutputFile( "target/test/prettyFormatTestDocumentWriter.xml" ) );
+            writer =
+                WriterFactory.newXmlWriter( getTestOutputFile( "target/test/prettyFormatTestDocumentWriter.xml" ) );
 
             assertNotNull( reader );
             assertNotNull( writer );
@@ -129,6 +134,12 @@ public class XmlUtilTest
         }
     }
 
+    /**
+     * <p>testPrettyFormatString.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testPrettyFormatString()
         throws Exception
     {
@@ -159,6 +170,12 @@ public class XmlUtilTest
         assertTrue( countEOL < StringUtils.countMatches( writer.toString(), XmlUtil.DEFAULT_LINE_SEPARATOR ) );
     }
 
+    /**
+     * <p>testPrettyFormatReaderWriter2.</p>
+     *
+     * @throws java.lang.Exception if any.
+     */
+    @Test
     public void testPrettyFormatReaderWriter2()
         throws Exception
     {
@@ -182,5 +199,5 @@ public class XmlUtilTest
             IOUtil.close( reader );
             IOUtil.close( writer );
         }
-    }   
+    }
 }
